@@ -2,7 +2,6 @@ import typing_extensions
 
 from groundx.paths import PathValues
 from groundx.apis.paths.v1_apikey import V1Apikey
-from groundx.apis.paths.v1_inventory import V1Inventory
 from groundx.apis.paths.v1_project_project_id import V1ProjectProjectId
 from groundx.apis.paths.v1_project import V1Project
 from groundx.apis.paths.v1_bucket_bucket_id import V1BucketBucketId
@@ -14,13 +13,12 @@ from groundx.apis.paths.v1_ingest_documents import V1IngestDocuments
 from groundx.apis.paths.v1_ingest_documents_id import V1IngestDocumentsId
 from groundx.apis.paths.v1_ingest_process_id import V1IngestProcessId
 from groundx.apis.paths.v1_preprocess import V1Preprocess
-from groundx.apis.paths.v1_search_project_id import V1SearchProjectId
+from groundx.apis.paths.v1_search_id import V1SearchId
 
 PathToApi = typing_extensions.TypedDict(
     'PathToApi',
     {
         PathValues.V1_APIKEY: V1Apikey,
-        PathValues.V1_INVENTORY: V1Inventory,
         PathValues.V1_PROJECT_PROJECT_ID: V1ProjectProjectId,
         PathValues.V1_PROJECT: V1Project,
         PathValues.V1_BUCKET_BUCKET_ID: V1BucketBucketId,
@@ -32,14 +30,13 @@ PathToApi = typing_extensions.TypedDict(
         PathValues.V1_INGEST_DOCUMENTS_ID: V1IngestDocumentsId,
         PathValues.V1_INGEST_PROCESS_ID: V1IngestProcessId,
         PathValues.V1_PREPROCESS: V1Preprocess,
-        PathValues.V1_SEARCH_PROJECT_ID: V1SearchProjectId,
+        PathValues.V1_SEARCH_ID: V1SearchId,
     }
 )
 
 path_to_api = PathToApi(
     {
         PathValues.V1_APIKEY: V1Apikey,
-        PathValues.V1_INVENTORY: V1Inventory,
         PathValues.V1_PROJECT_PROJECT_ID: V1ProjectProjectId,
         PathValues.V1_PROJECT: V1Project,
         PathValues.V1_BUCKET_BUCKET_ID: V1BucketBucketId,
@@ -51,6 +48,6 @@ path_to_api = PathToApi(
         PathValues.V1_INGEST_DOCUMENTS_ID: V1IngestDocumentsId,
         PathValues.V1_INGEST_PROCESS_ID: V1IngestProcessId,
         PathValues.V1_PREPROCESS: V1Preprocess,
-        PathValues.V1_SEARCH_PROJECT_ID: V1SearchProjectId,
+        PathValues.V1_SEARCH_ID: V1SearchId,
     }
 )
